@@ -1,5 +1,4 @@
-
-from request_signer.client.generic import Client, WebException
+from request_signer.client.generic import Client, WebException, django_backend
 
 
 __all__ = (
@@ -26,6 +25,11 @@ class BaseDjangoRestClient(Client):
     gets around this issue, but still uses full rest methods.
     """
 
+
+    def __init__(self, api_credentials=None):
+        api_credentials = api_credentials or django_backend.DjangoSettingsApiCredentialsBackend(self)
+        super(BaseDjangoRestClient, self).__init__(api_credentials)
+
     BASE_API_ENDPOINT = None
 
     def build_endpoint(self, group_key, item_key=None):
