@@ -1,6 +1,5 @@
 
 from optparse import make_option
-import sys
 
 from django.core.management import BaseCommand, CommandError
 from request_signer.models import AuthorizedClient, create_private_key
@@ -24,8 +23,8 @@ class Command(BaseCommand):
             key = create_private_key()
 
         client = AuthorizedClient.objects.create(client_id=client, private_key=key)
-        sys.stdout.write("Your client id is: '{0}'\n".format(client.client_id))
-        sys.stdout.write("Your private key is: '{0}'\n".format(client.private_key))
+        self.stdout.write("\nYour client id is: '{0}'\n".format(client.client_id))
+        self.stdout.write("Your private key is: '{0}'\n".format(client.private_key))
 
 
 
